COMMENT
Kinetic scheme model for non-NMDA excitatory synaptic transmission
based on

Holmes, W.R., and Levy, W.B.
Insights into associative long-term potentiation from 
computational models of NMDA receptor mediated calcium 
influx and intracellular calcium concentration changes. 
J. Neurophysiol. 63: 1148-1168, 1990.

    k       alp>
Rc <-- ARc <---> ARo
           <bet
Synaptic activation releases agonist which binds instantaneously to the 
closed form of the receptor/channel Rc.
Dissociation of ARc destroys agonist.

Reformulated to allow saturation of Rc this becomes
       k1
A + Rc --> ARc
where k1 is extremely fast and each synaptic activation adds A to the system

    k2
ARc --> Rc

     alp
ARc <---> ARo
     bet

where Rc + ARc + ARo = 1
ENDCOMMENT

NEURON {
	POINT_PROCESS ampakin
	NONSPECIFIC_CURRENT i
	RANGE i, g, gmax, e
}

UNITS {
	(mV) = (millivolt)
	(nA) = (nanoamp)
	(uS) = (microsiemens)
}

PARAMETER {
	gmax = 1	(uS)
	e = 0		(mV)
	k1 = 100	(/ms)  : make this >> k2, alp, and bet
	k2 = 1		(/ms)
	alp = 1		(/ms)
	bet = 0.5	(/ms)
}

CONSTANT {
	scalefactor = 2.92651	: so that w = 1 produces peak g = 1
	: NOTE--this value will be different for different k1, k2, alp, and bet
}

ASSIGNED {
	v	(mV)
	g	(uS)
	i	(nA)
}

STATE { A Rc ARc ARo }

BREAKPOINT {
	SOLVE states METHOD sparse
	g = gmax*ARo*scalefactor
	i = g*(v - e)
}

INITIAL {
	SOLVE states STEADYSTATE sparse
}

KINETIC states {
	~ A + Rc <-> ARc	(k1, 0)
	~ ARc <-> Rc		(k2, 0)
	~ ARc <-> ARo		(alp, bet)
	CONSERVE Rc + ARc + ARo = 1
}

NET_RECEIVE (w) {
	A = A+w
}
